@@ -255,6 +255,10 @@ bool analyse_argv( const char * const *argv,
                        || str_equal("-iprefix", a)
                        || str_equal("-iwithprefix", a)
                        || str_equal("-isystem", a)
+                       || str_equal("-iquote", a)
+                       || str_equal("-imultilib", a)
+                       || str_equal("-isysroot", a)
+                       || str_equal("-include", a)
                        || str_equal("-iwithprefixbefore", a)
                        || str_equal("-idirafter", a) ) {
                 args.append(a, Arg_Local);
